"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cli = void 0;
const mri = require("mri");
const libyear_1 = require("./libyear");
const package_manager_1 = require("./package-manager");
const configuration_1 = require("./configuration");
const print_1 = require("./print");
const validateThreshold = (threshold) => isNaN(Number(threshold)) ? null : Number(threshold);
const cli = async () => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    // parse cli args
    const argv = process.argv.slice(2);
    const args = mri(argv, { boolean: ["all", "json"], string: ["config"] });
    // validate cli options
    const packageManager = args["package-manager"];
    const all = args["all"];
    const json = args["json"];
    const { overrides, threshold } = await configuration_1.getConfiguration(args);
    const driftCollective = validateThreshold((_a = threshold === null || threshold === void 0 ? void 0 : threshold.drift) === null || _a === void 0 ? void 0 : _a.collective);
    const driftIndividual = validateThreshold((_b = threshold === null || threshold === void 0 ? void 0 : threshold.drift) === null || _b === void 0 ? void 0 : _b.individual);
    const pulseCollective = validateThreshold((_c = threshold === null || threshold === void 0 ? void 0 : threshold.pulse) === null || _c === void 0 ? void 0 : _c.collective);
    const pulseIndividual = validateThreshold((_d = threshold === null || threshold === void 0 ? void 0 : threshold.pulse) === null || _d === void 0 ? void 0 : _d.individual);
    const releasesCollective = validateThreshold((_e = threshold === null || threshold === void 0 ? void 0 : threshold.releases) === null || _e === void 0 ? void 0 : _e.collective);
    const releasesIndividual = validateThreshold((_f = threshold === null || threshold === void 0 ? void 0 : threshold.releases) === null || _f === void 0 ? void 0 : _f.individual);
    const majorCollective = validateThreshold((_g = threshold === null || threshold === void 0 ? void 0 : threshold.major) === null || _g === void 0 ? void 0 : _g.collective);
    const majorIndividual = validateThreshold((_h = threshold === null || threshold === void 0 ? void 0 : threshold.major) === null || _h === void 0 ? void 0 : _h.individual);
    const minorCollective = validateThreshold((_j = threshold === null || threshold === void 0 ? void 0 : threshold.minor) === null || _j === void 0 ? void 0 : _j.collective);
    const minorIndividual = validateThreshold((_k = threshold === null || threshold === void 0 ? void 0 : threshold.minor) === null || _k === void 0 ? void 0 : _k.individual);
    const patchCollective = validateThreshold((_l = threshold === null || threshold === void 0 ? void 0 : threshold.patch) === null || _l === void 0 ? void 0 : _l.collective);
    const patchIndividual = validateThreshold((_m = threshold === null || threshold === void 0 ? void 0 : threshold.patch) === null || _m === void 0 ? void 0 : _m.individual);
    // run libyear
    try {
        const report = await libyear_1.libyear(package_manager_1.getParsedPackageManager(packageManager !== null && packageManager !== void 0 ? packageManager : (await package_manager_1.getInferredPackageManager())), { all });
        const threshold = {
            driftCollective,
            driftIndividual,
            pulseCollective,
            pulseIndividual,
            releasesCollective,
            releasesIndividual,
            majorCollective,
            majorIndividual,
            minorCollective,
            minorIndividual,
            patchCollective,
            patchIndividual,
        };
        if (json) {
            console.log(JSON.stringify(report));
        }
        else {
            print_1.print(report, threshold, overrides);
        }
    }
    catch (error) {
        if (json) {
            console.log(JSON.stringify(error));
        }
        else {
            console.error(error.message);
        }
    }
};
exports.cli = cli;
