"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDependencies = void 0;
const lodash_1 = require("lodash");
const execute_1 = require("./execute");
const getParsedDependencies = async (packageManager, cmd) => {
    const stdout = await execute_1.execute(cmd);
    switch (packageManager) {
        case "pnpm":
            return lodash_1.merge(...JSON.parse(stdout));
        case "berry":
            return {
                dependencies: lodash_1.merge(...stdout
                    .split("\n")
                    .map((dependency) => JSON.parse(dependency))
                    .filter((dependency) => !/@workspace:/.test(dependency.value))
                    .map((dependency) => ({
                    [dependency.value.split(/@(npm|patch|workspace):/)[0]]: {
                        version: dependency.children.Version,
                    },
                }))),
                devDependencies: {},
            };
        case "npm":
        case "yarn":
        default:
            return JSON.parse(stdout);
    }
};
const getDependencies = async (packageManager, flags) => {
    var _a;
    const cmd = (_a = {
        berry: `yarn info ${(flags === null || flags === void 0 ? void 0 : flags.all) ? "--all" : ""} --json`,
        pnpm: `pnpm ${(flags === null || flags === void 0 ? void 0 : flags.all) ? "recursive" : ""} list --depth=0 --json`,
    }[packageManager]) !== null && _a !== void 0 ? _a : "npm ls --depth=0 --json --silent";
    const json = await getParsedDependencies(packageManager, cmd);
    return new Map(Object.entries({
        ...json.dependencies,
        ...json.devDependencies,
    }).map(([dependency, data]) => {
        var _a, _b;
        return [
            dependency,
            (_a = data.version) !== null && _a !== void 0 ? _a : (((_b = data.required) === null || _b === void 0 ? void 0 : _b.version) ||
                data.required).replace(/[<=>^~]+/u, ""),
        ];
    }));
};
exports.getDependencies = getDependencies;
