"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.libyear = void 0;
const semver_1 = require("semver");
const dates_1 = require("./dates");
const dependencies_1 = require("./dependencies");
const release_time_1 = require("./release-time");
const versions_1 = require("./versions");
const libyear = async (packageManager, flags) => {
    const awaitedDependencies = Array.from((await dependencies_1.getDependencies(packageManager, flags)).entries()).map(async ([dependency, currentVersion]) => {
        var _a, _b;
        const releaseTimeObj = (_a = (await release_time_1.getReleaseTime(packageManager, dependency))) !== null && _a !== void 0 ? _a : {};
        const releaseTimeMap = new Map(Object.entries(releaseTimeObj));
        const allVersionsMap = versions_1.getSanitisedReleases(releaseTimeMap);
        const stableVersionsMap = versions_1.getStableReleases(allVersionsMap);
        const allVersions = Array.from(allVersionsMap.keys());
        const stableVersions = Array.from(stableVersionsMap.keys());
        const latestAllVersion = semver_1.sort(allVersions).slice(-1)[0];
        const latestStableVersion = semver_1.sort(stableVersions).slice(-1)[0];
        const diffAllVersions = allVersions.slice(allVersions.findIndex((version) => version === currentVersion) + 1, allVersions.findIndex((version) => version === latestStableVersion) + 1);
        const diffStableVersions = diffAllVersions.filter((version) => stableVersions.includes(version));
        const drift = dates_1.calculateDrift(releaseTimeMap.get(currentVersion), releaseTimeMap.get(latestStableVersion));
        const pulse = dates_1.calculatePulse(releaseTimeMap.get(latestAllVersion));
        const releases = diffStableVersions.length;
        const major = versions_1.getReleasesByType([currentVersion, ...diffStableVersions], "major").length;
        const minor = versions_1.getReleasesByType([currentVersion, ...diffStableVersions], "minor").length;
        const patch = versions_1.getReleasesByType([currentVersion, ...diffStableVersions], "patch").length;
        const available = (_b = [latestStableVersion, latestAllVersion]
            .filter((version) => semver_1.valid(version))
            .find((version) => semver_1.compare(currentVersion, version, { includePrerelease: true }) < 0)) !== null && _b !== void 0 ? _b : "N/A";
        return {
            dependency,
            drift,
            pulse,
            releases,
            major,
            minor,
            patch,
            available,
        };
    });
    return Promise.all(awaitedDependencies);
};
exports.libyear = libyear;
