"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInferredPackageManager = exports.getParsedPackageManager = void 0;
const execa = require("execa");
const path = require("path");
const semver_1 = require("semver");
const getParsedPackageManager = (packageManager) => {
    switch (packageManager) {
        case "berry":
        case "npm":
        case "pnpm":
        case "yarn":
            return packageManager;
        default:
            return "npm";
    }
};
exports.getParsedPackageManager = getParsedPackageManager;
const getInferredPackageManager = async () => {
    const packageManager = path.basename(process.env.npm_execpath || "npm");
    if (packageManager.startsWith("yarn")) {
        const { stdout } = await execa.command("yarn --version");
        return semver_1.satisfies(stdout, "^0 || ^1") ? "yarn" : "berry";
    }
    else if (packageManager.startsWith("pnpm")) {
        return Promise.resolve("pnpm");
    }
    else {
        return Promise.resolve(exports.getParsedPackageManager(packageManager));
    }
};
exports.getInferredPackageManager = getInferredPackageManager;
