"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getViolations = exports.getTotals = void 0;
const constants_1 = require("./constants");
const isExcused = (dependency, overrides) => Object.entries(overrides).some(([pattern, { defer }]) => RegExp(pattern).test(dependency) && Date.now() < Date.parse(defer));
const isBreach = (value, limit, dependency, overrides) => limit != null && value > limit && !isExcused(dependency, overrides !== null && overrides !== void 0 ? overrides : {});
const getMatchingPattern = (dependency, overrides) => Object.keys(overrides).find((pattern) => RegExp(pattern).test(dependency));
const getTotals = (dependencies) => {
    const totals = new Map();
    dependencies.forEach((dependency) => {
        constants_1.metrics.forEach((metric) => {
            if (!isNaN(dependency[metric])) {
                const acc = totals.has(metric) ? totals.get(metric) : 0;
                const cur = dependency[metric];
                totals.set(metric, acc + cur);
            }
        });
    });
    return totals;
};
exports.getTotals = getTotals;
const getCollectiveViolations = (totals, threshold) => {
    const violations = new Map();
    constants_1.metrics.forEach((metric) => {
        const value = totals.get(metric);
        const limit = threshold === null || threshold === void 0 ? void 0 : threshold[`${metric}Collective`];
        if (isBreach(value, limit)) {
            violations.set(metric, value);
        }
    });
    return violations;
};
const getIndividualViolations = (dependencies, threshold, overrides) => {
    const violations = new Map();
    dependencies.forEach(({ dependency, ...rest }) => {
        constants_1.metrics.forEach((metric) => {
            var _a, _b;
            const value = rest[metric];
            const limit = (_b = (_a = overrides === null || overrides === void 0 ? void 0 : overrides[getMatchingPattern(dependency, overrides)]) === null || _a === void 0 ? void 0 : _a[metric]) !== null && _b !== void 0 ? _b : threshold === null || threshold === void 0 ? void 0 : threshold[`${metric}Individual`];
            if (isBreach(value, limit, dependency, overrides)) {
                if (!violations.has(metric)) {
                    violations.set(metric, new Map());
                }
                violations.get(metric).set(dependency, { threshold: limit, value });
            }
        });
    });
    return violations;
};
const getViolations = (dependencies, totals, threshold, overrides) => ({
    collective: getCollectiveViolations(totals, threshold),
    individual: getIndividualViolations(dependencies, threshold, overrides),
});
exports.getViolations = getViolations;
